import { ChainId, Network, TokenBridge, ChainAddress, TokenId, RpcConnection, NativeAddress } from '@wormhole-foundation/connect-sdk';
import { Connection } from '@solana/web3.js';
import { Program } from '@project-serum/anchor';
import { Wormhole as WormholeCore } from '../utils/types/wormhole';
import { TokenBridge as TokenBridgeContract } from '../utils/types/tokenBridge';
import { SolanaContracts } from '../contracts';
import { SolanaUnsignedTransaction } from '../unsignedTransaction';
import { AnySolanaAddress, SolanaChainName } from '../types';
export declare class SolanaTokenBridge implements TokenBridge<'Solana'> {
    readonly network: Network;
    readonly chain: SolanaChainName;
    readonly connection: Connection;
    readonly contracts: SolanaContracts;
    readonly chainId: ChainId;
    readonly tokenBridge: Program<TokenBridgeContract>;
    readonly coreBridge: Program<WormholeCore>;
    private constructor();
    static fromProvider(connection: RpcConnection<'Solana'>, contracts: SolanaContracts): Promise<SolanaTokenBridge>;
    isWrappedAsset(token: AnySolanaAddress): Promise<boolean>;
    getOriginalAsset(token: AnySolanaAddress): Promise<TokenId>;
    hasWrappedAsset(token: TokenId): Promise<boolean>;
    getWrappedAsset(token: TokenId): Promise<NativeAddress<'Solana'>>;
    isTransferCompleted(vaa: TokenBridge.VAA<'Transfer' | 'TransferWithPayload'>): Promise<boolean>;
    getWrappedNative(): Promise<NativeAddress<'Solana'>>;
    createAttestation(token: AnySolanaAddress, payer?: AnySolanaAddress): AsyncGenerator<SolanaUnsignedTransaction>;
    submitAttestation(vaa: TokenBridge.VAA<'AttestMeta'>, payer?: AnySolanaAddress): AsyncGenerator<SolanaUnsignedTransaction>;
    private transferSol;
    transfer(sender: AnySolanaAddress, recipient: ChainAddress, token: AnySolanaAddress | 'native', amount: bigint, payload?: Uint8Array): AsyncGenerator<SolanaUnsignedTransaction>;
    redeem(sender: AnySolanaAddress, vaa: TokenBridge.VAA<'Transfer' | 'TransferWithPayload'>, unwrapNative?: boolean): AsyncGenerator<SolanaUnsignedTransaction>;
    private postVaa;
    private createUnsignedTx;
}
//# sourceMappingURL=tokenBridge.d.ts.map